
!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:34'!
addAllFilesIn: aPathString
	"Adds all files in the directory specified by aPathString to the receiver file library"
	(SeasidePlatformSupport filesIn: aPathString)
		do: [ :each | self addFileAt: each ]! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:34'!
addFileAt: aFilename
	"Adds the file specified by aFilename to the current file library"
	self
		addFileAt: aFilename
		contents: (SeasidePlatformSupport
			contentsOfFile: aFilename
			binary: (self isBinaryAt: aFilename))! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:35'!
addFileAt: aFilename contents: aByteArrayOrString
	"Adds aByteArrayOrString contents to be served by the receiver as aFilename"
	self
		addFileNamed: (SeasidePlatformSupport localNameOf: aFilename)
		contents: aByteArrayOrString! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:36'!
addFileNamed: aFilename contents: aByteArrayOrString
	"Properly installs aByteArrayOrString in an adequate selector"

	| selector |
	selector := self asSelector: aFilename.
	(self isBinary: aFilename)
		ifTrue: [ self compileBinary: aByteArrayOrString selector: selector ]
		ifFalse: [ self compileText: aByteArrayOrString selector: selector ]! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:40'!
isBinary: aFilename
	"Answers true if aFilename content should be interpreted as binary data."
	| contentType |
	contentType := self mimetypeFor: (aFilename copyAfterLast: $.).
	^ (contentType beginsWith: 'text/') not and: [ contentType ~= 'application/x-javascript' ]! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:40'!
isBinaryAt: aResourceName
	"Answers true if aResourceName contents should be interpreted as binary data."

	^self isBinary: (SeasidePlatformSupport localNameOf: aResourceName)! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:38'!
refreshResources
	"Makes the receiver to have it's resources fresh from the files storage device"
	self 
		removeResources;
		reloadResources;
		yourself! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:38'!
reloadResources
	"Load the contents of the files found at a local 
	(to image path) directory named exacly like the receiver's class."
	
	self addAllFilesIn: (FileDirectory default fullPathFor: self name asString)! !

!WAFileLibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 23:29'!
removeResources

	self default filenames do:[:each|
		self default removeFile: each].! !

!WAApplication methodsFor: '*DF' stamp: 'sas 8/13/2007 19:40'!
deployFiles
	"Write in disk the files that the system use to serve from image
	in a path consistent with the receiver's configuration."

	self libraries do:[:aLibrary| aLibrary deployFiles]! !

!WALibrary class methodsFor: '*DF' stamp: 'sas 8/13/2007 20:03'!
deployFiles
	"Write in disk the files that the receiver use to serve as methods
	in a path consistent with it's configuration."
	
	self default deployFiles ! !

!WALibrary methodsFor: '*DF' stamp: 'sas 8/13/2007 20:43'!
deployFiles
	"Write in disk the files that the receiver use to serve as methods
	in a path consistent with it's configuration."

	self fileSelectors do:[:aFileSelector| |filename basePath fileStream baseDir contents|
		basePath := 'files'.
		filename := self asFilename: aFileSelector.
		FileDirectory default assureExistenceOfPath: basePath.
		baseDir := FileDirectory default directoryNamed: basePath.
		[baseDir assureExistenceOfPath: self name asString.
		contents := self documentForFile: filename.
		contents isString
			ifTrue:[
				fileStream :=  CrLfFileStream newFileNamed: ((baseDir directoryNamed: self name asString) fullNameFor: filename).
				fileStream ascii]
			ifFalse:[
				fileStream := (baseDir directoryNamed: self name asString) newFileNamed: filename.
				fileStream binary].
		fileStream nextPutAll: contents.
		] ensure:[fileStream close]]! !
